@@ -1,6 +1,4 @@
 /***************************************************************************
- *   ktlisttasks.h                                                         *
- *   --------------------------------------------------------------------  *
  *   KT list view item cron tasks folder.                                  *
  *   --------------------------------------------------------------------  *
  *   Copyright (C) 1999, Gary Meyer <gary@meyer.net>                       *
@@ -54,6 +52,11 @@ public:
   */
   virtual void refresh();
 
+/**
+  * Print all tasks.
+  */
+  virtual void print(KTPrint &printer)const;
+
 };
 
 #endif // KTLISTTASKS_H
