@@ -1,6 +1,4 @@
 /***************************************************************************
- *   kttask.cpp                                                            *
- *   --------------------------------------------------------------------  *
  *   KT task editor window implementation                                  *
  *   --------------------------------------------------------------------  *
  *   Copyright (C) 1999, Gary Meyer <gary@meyer.net>                       *
@@ -531,7 +529,7 @@ void KTTask::slotOK()
   QString sep("\n- ");
   bool showMessage(false);
 
-  if (QString(leCommand->text()) == "")
+  if (leCommand->text().isEmpty())
   {
     message += sep + i18n("the program to run");
     leCommand->setFocus();
@@ -641,7 +639,7 @@ void KTTask::slotOK()
   }
 
   // save work in process
-  if (cttask->user != "")
+  if (!cttask->user.empty())
   {
     cttask->user = QFile::encodeName(leUser->text());
   }
