@@ -1,6 +1,4 @@
 /***************************************************************************
- *   ktvariable.cpp                                                        *
- *   --------------------------------------------------------------------  *
  *   KT environment variable editor window implementation                  *
  *   --------------------------------------------------------------------  *
  *   Copyright (C) 1999, Gary Meyer <gary@meyer.net>                       *
@@ -130,14 +128,14 @@ void KTVariable::slotVariableChanged()
 
 void KTVariable::slotOk()
 {
-  if (QString(cmbVariable->currentText()) == "")
+  if (cmbVariable->currentText().isEmpty())
   {
     KMessageBox::information(this, i18n("Please enter the variable name."));
     cmbVariable->setFocus();
     return;
   }
 
-  if (QString(leValue->text()) == "")
+  if (leValue->text().isEmpty())
   {
     KMessageBox::information(this, i18n("Please enter the variable value."));
     cmbVariable->setFocus();
