@@ -38,10 +38,9 @@ void KNetworkConfigParser::runDetectionScript(QString platform){
   if (pathToProgram.isEmpty())
   {
     KMessageBox::error(0,
-                        i18n("Could not find the network detection scripts. Something is wrong with your installation.\n Please check that  \n{KDE_PATH}/%1 \nfile is present.").arg(BACKEND_PATH),
-                        i18n("Could Not Find Network Backend Script"));
+                        i18n("Could not find the backend script for the network configuration detection. Something is wrong with your installation.\n Please check that  \n{KDE_PATH}/%1 \nfile is present.").arg(BACKEND_PATH),
+                        i18n("Could Not Find Network Configuration Backend Script"));
       dialog->close();
-      exit(5);
       //kapp->quit();
   }
   else
@@ -63,10 +62,9 @@ void KNetworkConfigParser::runDetectionScript(QString platform){
     {
     // error handling
       KMessageBox::error(0,
-                        i18n("Could not execute network detection scripts. Something is wrong with your installation."),
-                        i18n("Could Not Launch Network Backend Script"));
+                        i18n("Could not execute backend script for the network configuration detection. Something is wrong with your installation."),
+                        i18n("Could Not Launch Network Configuration Backend Script"));
       dialog->close();
-      exit(5);
     }
   }
 }
@@ -93,10 +91,9 @@ void KNetworkConfigParser::listIfaces(const QString &platform){
  if ( !procDetect->start() )
   {
 // error handling
-    KMessageBox::error(0,
-                        i18n("Could not execute network detection scripts. Something is wrong with your installation."),
-                        i18n("Could Not Launch Network Backend Script"));
-    exit(5);
+      KMessageBox::error(0,
+                        i18n("Could not execute backend script for the network configuration detection. Something is wrong with your installation."),
+                        i18n("Could Not Launch Network Configuration Backend Script"));
   }
 }
 
@@ -113,7 +110,7 @@ void KNetworkConfigParser::readListIfacesSlot(){
     if ( !doc.setContent( xmlOuput.utf8(),false,&err,&x,&y  ) )
     {
       KMessageBox::error(0,
-                      i18n("Could not parse the XML file."),
+                      i18n("Could not parse the XML output from the network configuration backend."),
                       i18n("Error While Listing Network Interfaces"));
 //        qDebug("error: %s %d,%d",err.latin1(),x,y);
     }
@@ -186,18 +183,16 @@ void KNetworkConfigParser::readIfconfigOutput(){
   file instead of the gw configured by dhcp.
 */
 void KNetworkConfigParser::loadRoutingInfo( KRoutingInfo *routingInfo){
-//  routingInfo = NULL;
+#ifndef Q_OS_FREEBSD
   QFile f( "/proc/net/route");
   if ( !f.open(IO_ReadOnly) )
   {
-//    return routingInfo;
     KMessageBox::error(0,
                         i18n("Could not open file /proc/net/route."),
                         i18n("Could Not Open File"));
   }
   else
   {
-//    routingInfo = new KRoutingInfo();
     QTextStream t( &f );        // use a text stream
     QString s;
     while (!t.eof())
@@ -210,12 +205,12 @@ void KNetworkConfigParser::loadRoutingInfo( KRoutingInfo *routingInfo){
       if (destination == "00000000")
       {
         routingInfo->setGateway(hexIPv4ToDecIPv4(gw));
-//        routingInfo->setGateway(gw);
         routingInfo->setGatewayDevice(interface);
       }  
     }
   }
   f.close();
+#endif
 }
 QString
 KNetworkConfigParser::hexIPv4ToDecIPv4(const QString &hex)
@@ -225,6 +220,8 @@ KNetworkConfigParser::hexIPv4ToDecIPv4(const QString &hex)
   QString dec2 = "";
   QString temp = "";
   QString temp2 = "";
+
+#if Q_BYTE_ORDER == Q_LITTLE_ENDIAN
   temp = hex.mid(6,2);
   temp2 = temp2.setNum(temp.toInt(&ok,16));
   dec.append(temp2);
@@ -240,6 +237,23 @@ KNetworkConfigParser::hexIPv4ToDecIPv4(const QString &hex)
   temp = hex.mid(0,2);
   temp2 = temp2.setNum(temp.toInt(&ok,16));
   dec.append(temp2);
+#else
+  temp = hex.mid(0,2);
+  temp2 = temp2.setNum(temp.toInt(&ok,16));
+  dec.append(temp2);
+  dec.append('.');
+  temp = hex.mid(2,2);
+  temp2 = temp2.setNum(temp.toInt(&ok,16));  
+  dec.append(temp2);
+  dec.append('.');
+  temp = hex.mid(4,2);
+  temp2 = temp2.setNum(temp.toInt(&ok,16));  
+  dec.append(temp2);
+  dec.append('.');
+  temp = hex.mid(6,2);
+  temp2 = temp2.setNum(temp.toInt(&ok,16));
+  dec.append(temp2);
+#endif
 
   dec2 = dec;
   if (ok)
@@ -285,9 +299,9 @@ void KNetworkConfigParser::saveNetworkInfo(KNetworkInfo *networkInfo)
   procSaveNetworkInfo->addArgument( "--set" );
 
 //  KDetectDistroDlg* dialog = new KDetectDistroDlg(0, 0, true,QDialog::WStyle_Customize|QDialog::WStyle_NormalBorder|QDialog::WStyle_Title|QDialog::WStyle_SysMenu); //made it semi-modal
-  KDetectDistroDlg* dialog = new KDetectDistroDlg(0, 0);
+  KDetectDistroDlg* dialog = new KDetectDistroDlg((QWidget*)parent(), 0, true);
   dialog->setCaption(i18n("Reloading Network"));
-  dialog->text->setText(i18n("%1Please wait while reloading the network...%2").arg("<center>").arg("</center>"));
+  dialog->text->setText(i18n("%1Please wait while saving the network settings...%2").arg("<center>").arg("</center>"));
   dialog->show();
 
   xmlOuput = "";
@@ -296,16 +310,27 @@ void KNetworkConfigParser::saveNetworkInfo(KNetworkInfo *networkInfo)
   connect(procSaveNetworkInfo,SIGNAL(readyReadStdout()),this,SLOT(readFromStdoutSaveNetworkInfo()));
   connect(procSaveNetworkInfo,SIGNAL(wroteToStdin()),this,SLOT(sendNetworkInfoSavedSignalSlot()));
   connect(procSaveNetworkInfo,SIGNAL(processExited()),this,SLOT(listIfacesSlot()));
+
+  processRunning = true;
+  connect( procSaveNetworkInfo, SIGNAL(processExited()), this, SLOT(processExitedSlot()) );
    
   if ( !procSaveNetworkInfo->start() )
   {
-    KMessageBox::error(0,
-                        i18n("Could not execute network saving scripts. Something is wrong with your installation."),
-                        i18n("Could Not Launch Network Backend Script"));
+      KMessageBox::error(0,
+                        i18n("Could not execute backend script for the network configuration detection. Something is wrong with your installation."),
+                        i18n("Could Not Launch Network Configuration Backend Script"));
   }
 
   procSaveNetworkInfo->writeToStdin(xml);
 
+  //wait around until the process has finished, otherwise it becomes a zombie
+  while (processRunning) {  
+    kapp->processEvents();
+  }
+}
+
+void KNetworkConfigParser::processExitedSlot() {
+  processRunning = false;
 }
 
 void KNetworkConfigParser::addNetworkProfilesToXMLDoc(QDomDocument *doc, QDomNode *root, QPtrList<KNetworkInfo> profileList)
@@ -349,6 +374,10 @@ void KNetworkConfigParser::addNetworkInterfacesToXMLDoc(QDomDocument *doc, QDomN
   while ( (device = devIt.current()) != 0 )
   {
     ++devIt;
+    // if protocol is not specified, then should not have entry in config
+    if (device->getBootProto().isEmpty())
+      continue;
+
     QDomElement tag = doc->createElement( "interface" );
     tag.setAttribute("type",device->getType());
     root->appendChild( tag );
@@ -367,6 +396,13 @@ void KNetworkConfigParser::addNetworkInterfacesToXMLDoc(QDomDocument *doc, QDomN
         t = doc->createTextNode( device->getIpAddress() );
         innerTag.appendChild( t );
       }
+      if (!device->getGateway().isEmpty())
+      {
+        innerTag = doc->createElement( "gateway" );
+        configurationTag.appendChild( innerTag );
+        t = doc->createTextNode( device->getGateway() );
+        innerTag.appendChild( t );
+      }
       if (!device->getBroadcast().isEmpty())
       {
         innerTag = doc->createElement( "broadcast" );
@@ -635,6 +671,12 @@ KNetworkInterface * KNetworkConfigParser::getInterfaceInfo(QDomElement interface
               if (!e.text().isEmpty())
 	              tempDevice->setIpAddress(e.text());
             }
+            else if ( configNodeName == "gateway")
+            {
+              QDomElement e = configNode.toElement();
+              if (!e.text().isEmpty())
+            	  tempDevice->setGateway(e.text());
+            }
             else if ( configNodeName == "netmask" || configNodeName == "mask")
             {
               QDomElement e = configNode.toElement();
@@ -722,12 +764,6 @@ KNetworkInterface * KNetworkConfigParser::getInterfaceInfo(QDomElement interface
       tempDevice->setDescription(i18n("Wireless Network Device"));
   }
 
-  //If the backend reports that the interface is up (even if it isn't true),
-  //and the interface doesn't have an IP address assgined it means that effectively
-  //the interface is down and should be marked as inactive.
-  if (tempDevice->isActive() && tempDevice->getIpAddress().isEmpty())
-    tempDevice->setActive(false);
-    
   //Clear IP address settings if boot protocol is dhcp or bootp, in case that they are
   //setted in the config files.
   if ((tempDevice->getBootProto().lower() == "dhcp") || (tempDevice->getBootProto().lower() == "bootp"))
@@ -798,8 +834,8 @@ void KNetworkConfigParser::readNetworkInfo()
     if ( !doc.setContent( xmlOuput.utf8(),false,&err,&x,&y  ) )
     {
       KMessageBox::error(0,
-                      i18n("Could not parse the XML file."),
-                      i18n("Error"));
+                      i18n("Could not parse the XML output from the network configuration backend."),
+                      i18n("Error Loading The Network Configuration"));
 //        qDebug("error: %s %d,%d",err.latin1(),x,y);
     }
       
@@ -976,10 +1012,9 @@ void KNetworkConfigParser::loadSupportedPlatforms(){
  	if ( !procDetect->start() )
   {
 // error handling
-    KMessageBox::error(0,
-                        i18n("Could not list supported platforms. Something is wrong with your installation."),
-                        i18n("Could Not Launch Network Backend Script"));
-    exit(5);
+      KMessageBox::error(0,
+                        i18n("Could not execute backend script for the network configuration detection. Something is wrong with your installation."),
+                        i18n("Could Not Launch Network Configuration Backend Script"));
 	}
 
 }
@@ -992,8 +1027,8 @@ void KNetworkConfigParser::readSupportedPlatformsSlot(){
   if ( !doc.setContent( xmlOuput.utf8() ) )
   {
     KMessageBox::error(0,
-                         i18n("Could not parse the XML file of supported platforms."),
-                         i18n("Error"));
+                         i18n("Could not parse the list of supported platforms from the network configuration backend."),
+                         i18n("Error Obtaining Supported Platforms List"));
   }
   QDomElement root = doc.documentElement();
   QDomNode node = root.firstChild();
@@ -1111,9 +1146,9 @@ void KNetworkConfigParser::showSupportedPlatformsDialogSlot(){
       QPixmap distroImg(locate("data","knetworkconf/pixmaps/blackpanther.png"));
       dialog->klbDistroList->insertItem(distroImg, name);
     }
-    else if (key.contains("specifix"))
+    else if (key.contains("rpath"))
     {
-      QPixmap distroImg(locate("data","knetworkconf/pixmaps/specifix.png"));
+      QPixmap distroImg(locate("data","knetworkconf/pixmaps/rpath.png"));
       dialog->klbDistroList->insertItem(distroImg, name);
     }    
     else if (key.contains("vine"))
@@ -1135,12 +1170,10 @@ void KNetworkConfigParser::showSupportedPlatformsDialogSlot(){
     {
       QPixmap distroImg(locate("data","knetworkconf/pixmaps/ark.png"));
       dialog->klbDistroList->insertItem(distroImg, name);
-    }
-    
+    }    
   } 
   
   if (!dialog->exec())
-    //kapp->quit();
     emit setReadOnly(true);
   else
   {
