@@ -511,7 +511,7 @@ QStringList DEBAPT::readAptF()
 
 void DEBAPT::writeApt(const QStringList &list) {
   kdDebug() << "writeApt\n";
-  QString cmd = "sh -c \"echo -e '";
+  QString cmd = "sh -c \"/bin/echo -e '";
   for ( QStringList::ConstIterator it = list.begin(); it != list.end(); ++it ) {
     QString s = *it;
     s.replace("\""," ");
