@@ -16,8 +16,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -60,6 +60,7 @@ Options::Options(QWidget *parent)
 
     DCache = dc = opts->DCache;
     PCache = pc = opts->PCache;
+    privCmd = prc = opts->privCmd;
 
     if (DCache >= Opts::SESSION) {
       cacheObj::clearDCache(); // clear dir caches if needed
@@ -87,12 +88,21 @@ Options::Options(QWidget *parent)
       hosts->setTrapReturnKey(true);
 
       int i;
+      QString msgStr;
       for (i = 0; i < kpinterfaceN; i++)  {
 	if (kpinterface[i]) {
-	  QGroupBox *box = new QGroupBox(2,Qt::Horizontal,kpinterface[i]->name, framet, "box");
-	  packageHandle[i] =  new QCheckBox(i18n("Enable"), box);
+	  if (kpinterface[i]->hasProgram) {
+	    msgStr = kpinterface[i]->name;
+	  } else {
+	    msgStr = kpinterface[i]->name;
+	    msgStr = i18n("%1: %2 not found")
+	      .arg(kpinterface[i]->name)
+	      .arg(kpinterface[i]->errExe);
+	  }
+	  packageBox[i] = new QGroupBox(2,Qt::Horizontal,msgStr, framet, "box");
+	  packageHandle[i] =  new QCheckBox(i18n("Enable"), packageBox[i]);
 	  connect(packageHandle[i], SIGNAL(clicked()), this, SLOT(scanLocates()));
-	  locate[i] = new QPushButton(i18n("Location of Packages"),box);
+	  locate[i] = new QPushButton(i18n("Location of Packages"),packageBox[i]);
 	  connect(locate[i], SIGNAL(clicked()), kpinterface[i], SLOT(setLocation()));
 	} else {
 	  packageHandle[i] =  0;
@@ -142,22 +152,35 @@ Options::Options(QWidget *parent)
     }
 
     {
-      QWidget *page = addPage(i18n("&Misc"));
+      QWidget *page = addVBoxPage(i18n("&Misc"));
       QVBoxLayout *vf = new QVBoxLayout(page);
 
-      vf->setSpacing(KDialog::spacingHint());
+      //      vf->setSpacing(KDialog::spacingHint());
       vf->setMargin(0);
 
-      ssh = new QCheckBox(i18n("Use SSH for privileged commands"), page, "ssh");
-      vf->addWidget(ssh,0,AlignLeft);
-
+      bs = new QButtonGroup(page);
+      bs->setTitle(i18n("Execute Privileged Commands Using"));
+      connect( bs, SIGNAL(clicked(int)), SLOT(PPrivs(int)) );
+      
+      QVBoxLayout* vs = new QVBoxLayout( bs, 15, 10, "bs");
+      vs->addSpacing( bs->fontMetrics().height() );
+      
+      privs[0] = new QRadioButton(i18n("su command"),bs);
+      vs->addWidget(privs[0]);
+      
+      privs[1] = new QRadioButton(i18n("sudo command"),bs);
+      vs->addWidget(privs[1]);
+      
+      privs[2] = new QRadioButton(i18n("ssh command"),bs);
+      vs->addWidget(privs[2]);
+      
       valid = new QCheckBox(i18n("Verify file list"), page, "valid");
       vf->addWidget(valid,0,AlignLeft);
 
       pkgRead = new QCheckBox(i18n("Read information from all local package files"), page, "pkgr");
       vf->addWidget(pkgRead,0,AlignLeft);
 
-      vf->addStretch();
+      vf->addSpacing(100);
     }
 
     connect( this, SIGNAL(okClicked()), SLOT(apply_slot()) );
@@ -188,6 +211,7 @@ void Options::setValues() {
   //  kdDebug() << "setValues:\n";
   DCache = dc = opts->DCache;
   PCache = pc = opts->PCache;
+  privCmd = prc = opts->privCmd;
   CacheDir = opts->CacheDir;
 
   hosts->clear();
@@ -213,9 +237,9 @@ void Options::setValues() {
 
   dcache[DCache]->setChecked(TRUE);
   pcache[PCache]->setChecked(TRUE);
+  privs[privCmd]->setChecked(TRUE);
   cachedir->lineEdit()->setText(CacheDir);
 
-  ssh->setChecked(opts->useSSH);
   valid->setChecked(opts->VerifyFL);
   pkgRead->setChecked(opts->PkgRead);
 }
@@ -231,21 +255,26 @@ void Options::scanLocates() {
   for (i = 0; i < kpinterfaceN; i++) {
     if (kpinterface[i]) {
       //      kdDebug() << i << " " << hostName << " " << kpinterface[i]->hasRemote << "\n";
-      if (remote) {
-	if (kpinterface[i]->hasRemote) {
-	  packageHandle[i]->setEnabled(true);
-	  locate[i]->setEnabled(true);
+      if (kpinterface[i]->hasProgram) {
+	packageBox[i]->setEnabled(true);
+	if (remote) {
+	  if (kpinterface[i]->hasRemote) {
+	    packageHandle[i]->setEnabled(true);
+	    locate[i]->setEnabled(true);
+	  } else {
+	    packageHandle[i]->setEnabled(false);
+	    locate[i]->setEnabled(false);
+	  }
 	} else {
-	  packageHandle[i]->setEnabled(false);
-	  locate[i]->setEnabled(false);
+	  packageHandle[i]->setEnabled(true);
+	  if ( packageHandle[i]->isChecked()) {
+	    locate[i]->setEnabled(true);
+	  } else {
+	    locate[i]->setEnabled(false);
+	  }
 	}
       } else {
-	packageHandle[i]->setEnabled(true);
-	if ( packageHandle[i]->isChecked()) {
-	  locate[i]->setEnabled(true);
-	} else {
-	  locate[i]->setEnabled(false);
-	}
+	packageBox[i]->setEnabled(false);
       }
     }
   }
@@ -274,7 +303,6 @@ void Options::apply_slot()
   bool doReload = false;
   bool newHost  = false;
 
-  opts->useSSH = ssh->isChecked();
   opts->VerifyFL = valid->isChecked();
   opts->PkgRead = pkgRead->isChecked();
 
@@ -304,6 +332,7 @@ void Options::apply_slot()
 
   opts->DCache = dc;
   opts->PCache = pc;
+  opts->privCmd = prc;
   cachedir->lineEdit()->setText (QDir(cachedir->lineEdit()->text()).path().append("/")) ; // make sure that cache directory ends with "/"
   opts->CacheDir = cachedir->lineEdit()->text() ;
 
@@ -339,6 +368,12 @@ void Options::PPCache(int r)
   pc = r;
 }
 
+void Options::PPrivs(int r)
+{
+  kdDebug() << "Privs=" << r << "\n";
+  prc = r;
+}
+
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
@@ -368,17 +403,25 @@ void Opts::readSettings(const QString &initHost)
 
   DCache = config->readNumEntry("Dir_Cache",1);
   if (DCache >2) {
-    kdDebug() << "DCache=" << DCache << "\n";
     DCache = 1;
   }
   PCache = config->readNumEntry("Package_Cache",0);
   if (PCache >2) {
-    kdDebug() << "PCache=" << PCache << "\n";
     PCache = 0;
   }
   CacheDir = config->readPathEntry("Cache_Directory", QDir::homeDirPath() + "/.kpackage/");
 
-  useSSH = config->readNumEntry("Use_SSH",0);
+  // Backward compatability
+  bool useSSH = config->readNumEntry("Use_SSH",0);
+  privCmd = config->readNumEntry("Priv_Command", -1);
+  
+  if (privCmd == -1) {
+    if (useSSH) {
+      privCmd = SSHcmd;
+    } else {
+      privCmd = SUcmd;
+    }
+  }
   VerifyFL = config->readNumEntry("Verify_File_List",1);
   PkgRead = config->readNumEntry("Read_Package_files",0);
 }
@@ -409,7 +452,8 @@ void Opts::writeSettings()
   config->writeEntry("Package_Cache", PCache);
   config->writePathEntry("Cache_Directory", CacheDir);
 
-  config->writeEntry("Use_SSH",useSSH );
+  config->writeEntry("Priv_Command",privCmd );
+  
   config->writeEntry("Verify_File_List",VerifyFL );
   config->writeEntry("Read_Package_files", PkgRead);
 
