@@ -16,8 +16,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -79,13 +79,14 @@ private:
   bool verifyFL;
   bool PkgRead;
   bool fRemote;
-  int  DCache, dc, PCache, pc;
+  int  DCache, dc, PCache, pc, privCmd, prc;
   QString CacheDir;
 
   QVBoxLayout* vl;
 
   QVBoxLayout* vt;
   QGroupBox *framet;
+  QGroupBox *packageBox[kpinterfaceN];
   QCheckBox *packageHandle[kpinterfaceN];
   QPushButton *locate[kpinterfaceN];
 
@@ -105,6 +106,10 @@ private:
   QButtonGroup *bp;
   QRadioButton *pcache[3];
 
+  QVBoxLayout*  vs;
+  QButtonGroup *bs;
+  QRadioButton *privs[3];
+  
   KURLRequester *cachedir;
 
   QVBoxLayout* vr;
@@ -115,7 +120,6 @@ private:
   QGroupBox *framem;
   QCheckBox *valid;
 
-  QCheckBox *ssh;
 
 public slots:
     void scanLocates();
@@ -123,7 +127,8 @@ public slots:
     void cancel_slot();
     void PDCache(int);
     void PPCache(int);
-
+    void PPrivs(int);
+  
 private slots:
     void insHosts();
     void useRemote();
@@ -160,12 +165,14 @@ public:
 
   int PCache;
   // how much to cache uninstall packages
+  
+  int privCmd;
+  // which command to use to execute priveliged commands
+  enum {SUcmd=0, SUDOcmd=1, SSHcmd=2};
 
   QString CacheDir;
   // cache directory
 
-  bool useSSH;
-
   Opts(const QString &initHost);
   ~Opts();
 };
