@@ -1,5 +1,4 @@
-/* rpmInterface.cpp
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 */
@@ -17,8 +16,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -83,6 +82,8 @@ RPM::RPM():pkgInterface()
  infoList.append("version/%{VERSION}");
  infoList.append("release/%{RELEASE}");
  infoList.append("summary/%{SUMMARY}");
+ infoList.append("url/%{URL}");
+ infoList.append("architecture/%{ARCH}");
  infoList.append("group/%{GROUP}");
  infoList.append("distribution/%{DISTRIBUTION}");
  infoList.append("vendor/%{VENDOR}");
@@ -93,17 +94,23 @@ RPM::RPM():pkgInterface()
  infoList.append("provides/[%{PROVIDES}, ]");
  infoList.append("requires/[%{REQUIRENAME} (%{REQUIREFLAGS:depflags} %{REQUIREVERSION}), ]");
  infoList.append("description/[%{DESCRIPTION}]");
+
+ hasProgram = ifExe("rpm");
 }
 
  RPM::~RPM(){}
 
 bool RPM::isType(char *buf, const QString & /* fname */)
 {
-  if ((unsigned char)buf[0] == 0355 && (unsigned char)buf[1] == 0253 &&
-      (unsigned char)buf[2] == 0356 && (unsigned char)buf[3] == 0333 ) {
-    return true;
-  } else
+  if (hasProgram) {
+    if ((unsigned char)buf[0] == 0355 && (unsigned char)buf[1] == 0253 &&
+        (unsigned char)buf[2] == 0356 && (unsigned char)buf[3] == 0333 ) {
+     return true;
+    } else
+      return false;
+  } else {
     return false;
+  }
 }
 
 bool RPM::parseName(const QString &name, QString *n, QString *v)
@@ -196,8 +203,7 @@ void RPM::listInstalledPackages(QPtrList<packageInfo> *pki)
 packageInfo* RPM::collectInfo(QStringList &ln) {
 
   bool haveName = FALSE;
-  QDict<QString> *a = new QDict<QString>;
-  a->setAutoDelete(TRUE);
+  QMap<QString, QString> a;
 
   QString name, value;
 
@@ -216,13 +222,13 @@ packageInfo* RPM::collectInfo(QStringList &ln) {
 
     // kdDebug() << "name=" << name << " value='" << value << "'\n";
     if (name == "installtime") {
-      a->insert("install time", new QString(value));
+      a.insert("install time", value);
     } else if (name == "name") {
       if (!value.isEmpty())
 	haveName = TRUE;
-      a->insert("name", new QString(value.stripWhiteSpace()));    
+      a.insert("name", value.stripWhiteSpace());    
     } else if (name == "buildtime") {
-      a->insert("build-time", new QString(value));
+      a.insert("build-time", value);
     } else if (name == "requires") {
       value = value.replace(QRegExp("\\(\\)"),"");
       value = value.replace(QRegExp("\\( \\)"),"");
@@ -230,43 +236,44 @@ packageInfo* RPM::collectInfo(QStringList &ln) {
       if (value.endsWith(",")) {  
 	value.truncate(value.length()-1);
       }
-      a->insert("depends", new QString(value));
+      a.insert("depends", value);
     } else if (name == "provides") {
       int s = 0, n;
       QString t;
 
-      if (!(*a->find("name")).isEmpty()) {
+      if (!(*a.find("name")).isEmpty()) {
 	while ((n = value.find(",",s)) > 0) {
 	  t = value.mid(s,n-s);
 	  t = t.stripWhiteSpace();
 	  if (!t.isEmpty())
-	    provides.insert(t,new QString(*a->find("name")));
+	    provides.insert(t,new QString(*a.find("name")));
 	  s = n+1;
 	}
 	t = value.mid(s);
 	t = t.stripWhiteSpace();
 	if (!t.isEmpty())
-	  provides.insert(t,new QString(*a->find("name")));
+	  provides.insert(t,new QString(*a.find("name")));
 
 	value = value.stripWhiteSpace();
 	if (value.endsWith(",")) {  
 	  value.truncate(value.length()-1);
 	}
-	a->insert("provides", new QString(value));
+	a.insert("provides", value);
       }
     } else {
       if (!name.isEmpty())
-        a->insert(name, new QString(value));    
+        a.insert(name, value.stripWhiteSpace());    
     }
     
   }
 
-  QString *vers = a->find("version");
-  QString *rel = a->find("release");
-  if (vers && rel) {
-    *vers += "-";
-    *vers += *rel;
-    a->remove("release");
+  QString vers = a["version"];
+  QString rel = a["release"];
+  if (!vers.isEmpty() && !rel.isEmpty()) {
+    vers += "-";
+    vers += rel;
+    a["version"] = vers;
+    a.remove("release");
   }
 
   if (haveName) {
@@ -275,7 +282,6 @@ packageInfo* RPM::collectInfo(QStringList &ln) {
     i->fixup();
     return i;
   } else {
-    delete a;
     return 0;
   }
 }
@@ -311,7 +317,7 @@ QStringList RPM::getIChangeLog(packageInfo *p)
 
 
 // query an uninstalled package
-QStringList RPM::getUChangeLog(QString fn)
+QStringList RPM::getUChangeLog(const QString &fn)
 {
   QString cmd = "rpm -q --changelog -p ";
   cmd += quotePath(fn);
@@ -373,7 +379,7 @@ QStringList RPM::getIFileList(packageInfo *p)
 
 
 // query an uninstalled package
-QStringList RPM::getUFileList(QString fn)
+QStringList RPM::getUFileList(const QString &fn)
 {
   QString cmd = "rpm -q -l -p ";
   cmd += quotePath(fn);
@@ -392,7 +398,7 @@ packageInfo *RPM::getPackageInfo(char mode, const QString &name, const QString &
     return getUPackageInfo(name);
 }
 
-packageInfo *RPM::getIPackageInfo( QString name)
+packageInfo *RPM::getIPackageInfo( const QString &name )
 {
   // query an installed package!
   QString cmd = "rpm -q";
@@ -409,7 +415,7 @@ packageInfo *RPM::getIPackageInfo( QString name)
   return pki;
 }
 
-packageInfo *RPM::getUPackageInfo( QString name)
+packageInfo *RPM::getUPackageInfo( const QString &name )
 {
   // query an uninstalled package
   QString cmd = "rpm -q";
@@ -423,14 +429,14 @@ packageInfo *RPM::getUPackageInfo( QString name)
     pki->updated = TRUE;
     pki->packageState = packageInfo::AVAILABLE;
     if (pki->hasProperty("install time"))
-      pki->info->remove("install time");
+      pki->info.remove("install time");
     collectDepends(pki,name,1);
   }
 
   return pki;
 }
 
-QString RPM::provMap(QString p)
+QString RPM::provMap( const QString &p )
 {
   QString *r = provides[p];
   if (r) {
@@ -457,12 +463,12 @@ void RPM::collectDepends(packageInfo *p, const QString &name, int src)
 
   if (list.count() > 0) {
      QStringList::Iterator it = list.begin();
-     int pt = (*it).findRev(":");
+     int pt = (*it).find(":");
      if (pt > 0) {
        QString s = (*it).mid(pt+1);
        if (!s.isEmpty()) {
 	 //	 kdDebug() << "S=" << s << "\n";
-	 p->info->insert("unsatisfied dependencies",new QString(s));
+	 p->info.insert("unsatisfied dependencies", s);
        }
      }
   }
@@ -586,7 +592,7 @@ QString RPM::doinstP(int installFlags, const QStringList &files, bool &test)
    return pkgInterface::verify(p,files);}
 
 //////////////////////////////////////////////////////////////////////////////
-QStringList RPM::FindFile(const QString &name) {
+QStringList RPM::FindFile(const QString &name, bool) {
   QString cmd = "rpm -q -a --filesbypkg";
     
   QStringList list =  kpty->run(cmd);
@@ -608,11 +614,10 @@ QStringList RPM::FindFile(const QString &name) {
 }
 
 //////////////////////////////////////////////////////////////////////////////
-QString RPM::quotePath( QString path) {
-  QString s = "'";
-  s += path.replace(" ","\\ ");
-  s += "'";
-  return s;
+QString RPM::quotePath( const QString &path) {
+  QString s = path;
+  s = s.replace(" ","\\ ");
+  return ( "'" + s + "'" );
 }
 
 //////////////////////////////////////////////////////////////////////////////
