@@ -14,8 +14,8 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
 #include <qtooltip.h>
@@ -140,7 +140,7 @@ void mainWidget::init()
   md->clearUsers();
   md->clearGroups();
   kug->init();
-  rw = ! ( kug->getUsers().getCaps() & KUsers::Cap_ReadOnly );
+  rw = ! ( kug->getUsers().getCaps() & KU::KUsers::Cap_ReadOnly );
   kdDebug() << "Users rw()" << rw << endl;
   actionCollection()->action("add_user")->setEnabled( rw );
   actionCollection()->action("edit_user")->setEnabled( rw );
@@ -157,7 +157,7 @@ void mainWidget::init()
     disconnect( md, SIGNAL(userSelected(bool)), 0, 0 );
   }
 
-  rw = ! ( kug->getGroups().getCaps() & KGroups::Cap_ReadOnly );
+  rw = ! ( kug->getGroups().getCaps() & KU::KGroups::Cap_ReadOnly );
   kdDebug() << "Groups rw()" << rw << endl;
   actionCollection()->action("add_group")->setEnabled( rw );
   actionCollection()->action("edit_group")->setEnabled( rw );
