@@ -1,3 +1,31 @@
+/* String.cc
+**
+** Copyright (C) 2000,2001 by Bernhard Rosenkraenzer
+**
+** Contributions by A. Seigo and W. Bastian.
+**
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
 #define _GNU_SOURCE 1
 #include <features.h>
 #include <string.h>
@@ -222,7 +250,19 @@ String &String::replace(String const &what, String const &with, bool all) const
 	}
 	return *result;
 }
+String String::escapeForRegExp(String const &s)
+{
+	static const char meta[] = "$()*+.?[\\]^{|}";
+	String quoted = s;
+	int i = 0;
 
+	while ( i < (int) quoted.length() ) {
+		if ( strchr(meta, quoted.at(i)) != 0 )
+			quoted.insert( i++, "\\" );
+		i++;
+	}
+	return quoted;
+}
 StringList::StringList(String const &s)
 {
 	clear();
